@@ -1,18 +1,23 @@
 import markdown
 
 from .markdown_extension import DisplayMathProcessor, InlineMathProcessor
+from .settings import PelicanMathSettings
 
 
 class PelicanMathExtension(markdown.Extension):
-    def __init__(self):
+    def __init__(self, settings: PelicanMathSettings):
         super().__init__()
 
+        self.settings = settings
+
     def extendMarkdown(self, md: markdown.core.Markdown):
         md.inlinePatterns.register(
-            InlineMathProcessor(r"(?<!\\|\$)\$((?:[^$]|\\\$)+)(?<!\\)\$(?!\$)", md),
+            InlineMathProcessor(
+                r"(?<!\\|\$)\$((?:[^$]|\\\$)+)(?<!\\)\$(?!\$)", self.settings, md
+            ),
             "inline_math",
             200,
         )
         md.parser.blockprocessors.register(
-            DisplayMathProcessor(md.parser), "display_math", 200
+            DisplayMathProcessor(self.settings, md.parser), "display_math", 200
         )
